@@ -34,8 +34,8 @@ def get_selects(sql):
     rm.reverse()
     for r1, r2 in rm:
         sqlSelect = sqlSelect[0:r1] + sqlSelect[r2 + 1:]
-    sqlSelect = sqlSelect.replace(" ", "").replace(
-        "distinct", "").lower().split(",")
+    sqlSelect = (sqlSelect.replace(" ", "").replace("distinct", "")
+                 .replace("\n", "").lower().split(","))
     return sqlSelect
 
 
@@ -46,8 +46,8 @@ class Database(object):
     si no s'especifica el contrari.
     """
 
-    def set_debug(self):
-        self.DEBUG = True
+    def set_debug(self, deb=True):
+        self.DEBUG = deb
 
     DEBUG = False
     NUM2L = (["01", "02", "03", "04", "05", "06", "07", "08", "09", "10",
@@ -68,7 +68,8 @@ class Database(object):
         'cataleg': (lambda: random.randint(1, 32)),
         'scs_codi': (lambda: "00089"),
         'ics_desc': (lambda: "ABS AMPOSTA"),
-        'data_type': (lambda: random.choice(["date", "int", "bigint", "double", "varchar", "DATE", "DATE_J", "DATETIME", "TIMESTAMP(6)", "NUMBER", "VARCHAR2", "CHAR"]))
+        'data_type': (lambda: random.choice(["date", "int", "bigint", "double", "varchar", "DATE", "DATE_J", "DATETIME", "TIMESTAMP(6)", "NUMBER", "VARCHAR2", "CHAR"])),
+        'sector': lambda: random.choice(['6416', '6844', '6838', '6731', '6735', '6625', '6521', '6102', '6519', '6626', '6522', '6839', '6523', '6211', '6520', '6209', '6728', '6310', '6627', '6837', '6734'])
     }
 
     def __init__(self, instance, schema, retry=None):
@@ -107,6 +108,8 @@ class Database(object):
                         data[select] = Database.TEMPLATE[select]()
                 elif select != 'val':
                     data[select] = str(random.randint(-50, -10))
+                if "convert" in select:
+                    data[select] = data[select].encode()
         sorted_data = sorted(data.items(), key=lambda x: sqlSelect.index(x[0])
                              if x[0] in sqlSelect else
                              len(sqlSelect) + 1)
